.. _mission:

=======
Mission
=======

sktime enables understandable and composable machine learning with time
series. It provides `scikit-learn <https://scikit-learn.org/stable/>`__
compatible algorithms and model composition tools, supported by a clear
taxonomy of learning tasks, with instructive documentation and a
friendly community.

Our :ref:`roadmap` gives more details on how we try to achieve our mission.
